@@ -9,9 +9,9 @@
 """ version information for lswifi """
 
 __title__ = "lswifi"
-__description__ = "a CLI Wi-Fi scanner tool for Windows"
+__description__ = "a CLI-centric Wi-Fi scanning tool for Windows"
 __url__ = "https://github.com/joshschmelzle/lswifi"
-__version__ = "0.1.32"
+__version__ = "0.1.34"
 __author__ = "Josh Schmelzle"
 __author_email__ = "josh@joshschmelzle.com"
 __license__ = "BSD-3-Clause"
